@@ -73,7 +73,7 @@ class VarCls:
     ---------
     name (str): variable name.  Default is empty.
     pattern (str): a regex pattern.  Default is empty.
-    option (str): a option for value assignment.  Default is empty.
+    option (str): an option for value assignment.  Default is empty.
 
     Properties
     ----------
@@ -84,7 +84,7 @@ class VarCls:
     def __init__(self, name='', pattern='', option=''):
         self.name = str(name).strip()
         self.pattern = str(pattern)
-        self.option = ','.join(re.split(r'\s*_\s*', str(option)))
+        self.option = ','.join(re.split(r'\s*_\s*', str(option).title()))
         self.option = self.option.replace(' ', '')
 
     @property
@@ -94,8 +94,10 @@ class VarCls:
     @property
     def value(self):
         if self.option:
+            self.option = ','.join(re.split(r'\s*_\s*', str(self.option).title()))
+            self.option = self.option.replace(' ', '')
             fmt = 'Value {} {} ({})'
-            value = fmt.format(self.name, self.option, self.pattern)
+            value = fmt.format(self.option, self.name, self.pattern)
         else:
             fmt = 'Value {} ({})'
             value = fmt.format(self.name, self.pattern)
